# Instractions

#### This is our test project.

#### Please install this package
```
pip install functions-by-shukur
```

#### Please install this packages
```
 pip install functions-by-shukur==VERSION_NUMBER
```